# LICENSE HEADER MANAGED BY add-license-header
#
# Copyright (c) 2023-2024 Blue Brain Project, EPFL.
#
# This file is part of axon-projection.
# See https://github.com/BlueBrain/axon-projection for further info.
#
# SPDX-License-Identifier: Apache-2.0
#

"""Handy module to convert acronyms to their full names, and output to tex table."""

import ast

import pandas as pd

# Path to your CSV file
csv_file_path = (
    "/gpfs/bbp.cscs.ch/data/project/proj135/home/petkantc/axon/axonal-projection/"
    "axon_projection/out_a_p_12_obp_atlas/region_names_df.csv"
)

# Provided set of acronyms
acronyms_set = [
    "fiber tracts",
    "ec",
    "fp",
    "cpd",
    "or",
    "cing",
    "alv",
    "dhc",
    "fr",
    "hbc",
    "scwm",
    "P",
    "HY",
    "ZI",
    "PH",
    "DMH",
    "PVi",
    "AV",
    "IAD",
    "IAM",
    "LD",
    "LH",
    "MH",
    "IGL",
    "CL",
    "Eth",
    "LP",
    "PO",
    "MD",
    "PT",
    "PVT",
    "RT",
    "LGd",
    "ec",
    "SPFm",
    "VAL",
    "SPFm",
    "VAL",
    "CA",
    "VP",
    "VP",
    "or",
    "TH",
    "MB",
    "TH",
    "MB",
    "alv",
    "PRC",
    "NPC",
    "PRC",
    "NPC",
    "GPi",
    "GPi",
    "dhc",
    "CA",
    "DG",
    "CA",
    "DG",
    "fp",
    "HPF",
    "APr",
    "HPF",
    "APr",
    "ENT",
    "POST",
    "ENT",
    "POST",
    "ProS",
    "SUB",
    "ProS",
    "SUB",
    "ECT6a",
    "PERI6a",
    "TEa6b",
    "VISa",
    "VISrl",
    "VISa",
    "VISrl",
    "RSPagl",
    "RSPagl",
    "RSPd",
    "RSPd",
    "RSPv",
    "RSPv",
    "ProS",
    "RSPv",
    "TEa6a",
    "VISam",
    "TEa6b",
    "VISam",
    "TEa6a",
    "VISl",
    "VISli",
    "VISp",
    "VISl",
    "VISli",
    "VISp",
    "SUB",
    "VISpl",
    "VISpl",
    "VISpm",
    "VISpm",
    "VISpor",
    "VISpor",
    "VISpor",
    "root",
    "V3",
    "bic",
    "fp",
    "or",
    "alv",
    "fx",
    "dhc",
    "st",
    "sm",
    "root",
    "HY",
    "LHA",
    "ZI",
    "LM",
    "MM",
    "TM",
    "AD",
    "AM",
    "AV",
    "LD",
    "LGv",
    "PT",
    "RT",
    "LGd",
    "MG",
    "VAL",
    "VP",
    "TH",
    "PAL",
    "BST",
    "CA",
    "DG",
    "HPF",
    "ENT",
    "PAR",
    "POST",
    "PRE",
    "ProS",
    "SUB",
    "PIR",
    "MOp",
    "MOs",
    "SSp",
    "SSs",
    "VISC",
    "AUD",
    "PERI",
    "ECT",
    "GU",
    "ORB",
    "ACA",
    "RSP",
    "FRP",
    "PL",
    "ILA",
    "TEa",
    "MOp1",
    "MOp2",
    "MOp3",
    "MOp5",
    "MOp6a",
    "MOp6b",
    "MOp",
    "MOs",
    "SSp",
    "SSs",
    "CP",
    "PG",
    "SPVI",
    "Isocortex",
    "OLF",
    "CTXsp",
    "STR",
    "PAL",
    "TH",
    "HY",
    "MB",
    "PG",
    "MY",
    "MOs2",
    "MOp6a",
    "SSp-m4",
    "MOs6a",
    "MOs5",
    "SSs6a",
    "ACAd5",
    "SSp-ul5",
    "ORBl6a",
    "SSp-m6a",
    "MOs3",
    "SSp-n5",
    "MOp5",
    "RSPv5",
    "MOp3",
    "SSp-m5",
    "ACAd6a",
    "SSs5",
    "SSp-m3",
    "MOp2",
    "MOp1",
    "MOs1",
    "ACAd5",
    "ACAd6a",
    "AId5",
    "AId6a",
    "AUDv5",
    "GU5",
    "MOp2",
    "MOp3",
    "MOp5",
    "MOp6a",
    "MOs2",
    "MOs3",
    "MOs5",
    "MOs6a",
    "ORBl6a",
    "RSPagl2",
    "RSPv5",
    "SSp-bfd2",
    "SSp-bfd3",
    "SSp-bfd4",
    "SSp-bfd5",
    "SSp-bfd6a",
    "SSp-ll5",
    "SSp-ll6a",
    "SSp-m3",
    "SSp-m4",
    "SSp-m5",
    "SSp-m6a",
    "SSp-n3",
    "SSp-n5",
    "SSp-n6a",
    "SSp-ul2",
    "SSp-ul3",
    "SSp-ul4",
    "SSp-ul5",
    "SSp-un5",
    "SSs2",
    "SSs3",
    "SSs4",
    "SSs5",
    "SSs6a",
    "TEa5",
    "VISa2",
    "VISal2",
    "VISl6a",
    "VISp2",
    "VISp3",
    "VISrl3",
    "MOp",
    "MOs",
    "SSp",
    "SSs",
    "VISC",
    "AUD",
    "PERI",
    "ECT",
    "GU",
    "ORB",
    "ACA",
    "RSP",
    "FRP",
    "PL",
    "ILA",
    "TEa",
    "VIS",
    "PTLp",
    "ACAd5",
    "ACAv5",
    "AId5",
    "AIp5",
    "AIv5",
    "AUDd5",
    "AUDp5",
    "AUDpo5",
    "AUDv5",
    "ECT5",
    "FRP5",
    "GU5",
    "ILA5",
    "MOp5",
    "MOs5",
    "ORBl5",
    "ORBm5",
    "ORBvl5",
    "PERI5",
    "PL5",
    "RSPagl5",
    "RSPd5",
    "RSPv5",
    "SSp-bfd-A1-5",
    "SSp-bfd-A2-5",
    "SSp-bfd-A3-5",
    "SSp-bfd-Alpha-5",
    "SSp-bfd-B1-5",
    "SSp-bfd-B2-5",
    "SSp-bfd-B3-5",
    "SSp-bfd-B4-5",
    "SSp-bfd-Beta-5",
    "SSp-bfd-C1-5",
    "SSp-bfd-C2-5",
    "SSp-bfd-C3-5",
    "SSp-bfd-C4-5",
    "SSp-bfd-C5-5",
    "SSp-bfd-C6-5",
    "SSp-bfd-D1-5",
    "SSp-bfd-D2-5",
    "SSp-bfd-D3-5",
    "SSp-bfd-D4-5",
    "SSp-bfd-D5-5",
    "SSp-bfd-D6-5",
    "SSp-bfd-D7-5",
    "SSp-bfd-D8-5",
    "SSp-bfd-Delta-5",
    "SSp-bfd-E1-5",
    "SSp-bfd-E2-5",
    "SSp-bfd-E3-5",
    "SSp-bfd-E4-5",
    "SSp-bfd-E5-5",
    "SSp-bfd-E6-5",
    "SSp-bfd-E7-5",
    "SSp-bfd-E8-5",
    "SSp-bfd-Gamma-5",
    "SSp-bfd5",
    "SSp-ll5",
    "SSp-m5",
    "SSp-n5",
    "SSp-tr5",
    "SSp-ul5",
    "SSp-un5",
    "SSs5",
    "TEa5",
    "VISC5",
    "VISa5",
    "VISal5",
    "VISam5",
    "VISl5",
    "VISli5",
    "VISp5",
    "VISpl5",
    "VISpm5",
    "VISpor5",
    "VISrl5",
    "AI",
]

# Dictionary to store acronym to name mappings
acronym_name_mapping = {}


# Function to match acronyms and get their names
def find_acronym_names(acronyms_set, csv_file_path):
    """Find the acronym names in the provided CSV file and return a dictionary."""
    # Read the CSV file into a pandas DataFrame
    df = pd.read_csv(csv_file_path)

    # Dictionary to store acronym to name mappings
    acronym_name_mapping = {}

    # Iterate through each row in the DataFrame
    for index, row in df.iterrows():
        # Convert the 'acronyms' and 'names' columns from string to lists
        acronyms_list = ast.literal_eval(row["acronyms"])
        names_list = ast.literal_eval(row["names"])

        # Create a mapping of each acronym to its corresponding name
        for acronym, name in zip(acronyms_list, names_list):
            acronym_name_mapping[acronym] = name

    # Search for the names corresponding to the acronyms in the provided set
    result = {acronym: acronym_name_mapping.get(acronym) for acronym in acronyms_set}

    return result


# Find and print the acronym names
acronym_names = find_acronym_names(acronyms_set, csv_file_path)
# sort the acronym names dict by alphabetical order
acronym_names = dict(sorted(acronym_names.items()))
# make a df of the dict
df = pd.DataFrame.from_dict(acronym_names, orient="index")
df.index.name = "Acronym"
df.columns = ["Name"]
# output it in latex
df.to_latex("acronyms_to_names.tex")
